import java.awt.Color;
import java.text.DateFormatSymbols;
import java.util.Locale;

import javax.swing.JFrame;
import javax.swing.SwingUtilities;

import com.mindfusion.common.DateTime;
import com.mindfusion.drawing.Colors;
import com.mindfusion.drawing.SolidBrush;
import com.mindfusion.spreadsheet.Cell;
import com.mindfusion.spreadsheet.CellRange;
import com.mindfusion.spreadsheet.HorizontalAlignment;
import com.mindfusion.spreadsheet.IStyle;
import com.mindfusion.spreadsheet.Measure;
import com.mindfusion.spreadsheet.VerticalAlignment;
import com.mindfusion.spreadsheet.Workbook;
import com.mindfusion.spreadsheet.Worksheet;
import com.mindfusion.spreadsheet.WorksheetView;


public class Calendar
{
	public static void main(String[] args)
	{			
		SwingUtilities.invokeLater(new Runnable()
		{
			public void run()
			{
				MainWindow window = new MainWindow();
				window.setTitle("JSpreadsheet Sample: Calendar");
				window.setVisible(true);
			}
		});
	}
	
	public static class MainWindow extends JFrame
	{
		public MainWindow()
		{
			setDefaultCloseOperation(EXIT_ON_CLOSE);
			setSize(1280, 1024);

			Workbook workbook = new Workbook();
			Worksheet worksheet = workbook.getWorksheets().add();

			WorksheetView view = new WorksheetView();
			view.setWorksheet(worksheet);
			add(view);

			Worksheet activeSheet = worksheet;

			activeSheet.beginInit();
			CellRange heading = activeSheet.getCellRanges().get("B2:H2");
			heading.merge();
			Cell headingCell = activeSheet.getCells().get("B2");
			headingCell.setData(DateTime.today());
			IStyle headingStyle = headingCell.getStyle();
			headingStyle.setFormat("MMMM, yyyy");
			headingStyle.setHorizontalAlignment(HorizontalAlignment.Center);
			headingStyle.setVerticalAlignment(VerticalAlignment.Middle);
			headingStyle.setBackground(new SolidBrush(new Color(0, 52, 102)));
			headingStyle.setFontSize(16d);
			headingStyle.setFontBold(true);
			headingStyle.setTextColor(Colors.White);
			DateFormatSymbols symbols = new DateFormatSymbols(Locale.US);
			for (int i = 1; i <= 7; i++)
				activeSheet.getCells().get(i, 2).setData(symbols.getShortWeekdays()[i]);
			CellRange subheading = activeSheet.getCellRanges().get("B3:H3");
			IStyle subheadingStyle = subheading.getStyle();
			subheadingStyle.setBackground(new SolidBrush(new Color(102, 154, 204)));
			subheadingStyle.setHorizontalAlignment(HorizontalAlignment.Center);
			subheadingStyle.setVerticalAlignment(VerticalAlignment.Middle);
			subheadingStyle.setFontBold(true);
			CellRange content = activeSheet.getCellRanges().get("B4:H9");
			IStyle contentStyle = content.getStyle();
			contentStyle.setBackground(new SolidBrush(new Color(224, 233, 233)));
			contentStyle.setHorizontalAlignment(HorizontalAlignment.Center);
			contentStyle.setVerticalAlignment(VerticalAlignment.Middle);
			contentStyle.setFormat("d");
			String formula = "=IF(MONTH(DATE(YEAR(B2),MONTH(B2),1))<>MONTH(DATE(YEAR(B2),MONTH(B2),1)-(WEEKDAY(DATE(YEAR(B2),MONTH(B2),1))-1)+(ROW()-4)*7+(COLUMN()-1)-1),\"\",DATE(YEAR(B2),MONTH(B2),1)-(WEEKDAY(DATE(YEAR(B2),MONTH(B2),1))-1)+(ROW()-4)*7+(COLUMN()-1)-1)";
			for (int i = 0; i < 7; i++)
			{
				for (int j = 0; j < 6; j++)
					activeSheet.getCells().get(content.getLeft() + i, content.getTop() + j).setData(formula);
			}
			activeSheet.getColumns().get(1, 7).setWidth(new Measure("30pt"));
			activeSheet.getRows().get(1).setHeight(new Measure("20pt"));
			activeSheet.getRows().get(2, 8).setHeight(new Measure("16pt"));
			activeSheet.endInit();
		}

		private static final long serialVersionUID = 1L;
	}
}